Result
------

The result module contains the class ``FitResult`` that stores the result of a fit. It contains various different information about the fit, such as the minimum value of the loss, the parameters at the minimum, the covariance matrix, the correlation matrix, the edm, the fmin and more.

For an overview on the `available methods, see the tutorial <https://zfit-tutorials.readthedocs.io/en/latest/tutorials/components/05%20-%20Exploring%20the%20FitResult.html>`_.

.. autosummary::
    :toctree: _generated/result

    zfit.result.FitResult
    zfit.result.compute_errors
